@@ -30,7 +30,7 @@ class MemmapRecordExporter(DataExporter, IterDataPipe, MapDataPipe):
     def saveShape(self, dataId, lengths, saveShape, tmp=False):
         shape = np.array((lengths, saveShape), dtype="object")
         np.save(self.getShapeFilePath(dataId, tmp=tmp), shape)
-        self.log("saved %s: %s" % (dataId, str(shape)))
+        self.log("saved %s: Shape %s (%i records)" % (dataId, str(saveShape), len(lengths)))
 
     def finishShape(self, dataId):
         self.saveShape(dataId, *self.currentArrayShapes[dataId], tmp=False)
@@ -49,7 +49,7 @@ class MemmapRecordExporter(DataExporter, IterDataPipe, MapDataPipe):
         """fills the array from a list of 2-dimensional arrays"""
         array = np.concatenate(arrayList)
         array = np.expand_dims(array, 0)
-        memmap = self.stream(dataId, {"dtype": "float32", "mode": "w+", "shape": array.shape})
+        memmap = self.stream(dataId, {"dtype": self.getOption("dtype"), "mode": "w+", "shape": array.shape})
         memmap[:, :, :] = array
         memmap.flush()
         del memmap
@@ -73,7 +73,7 @@ class MemmapRecordExporter(DataExporter, IterDataPipe, MapDataPipe):
         memmap = None
         if dataId not in self.currentArrayShapes:
             self.currentArrayShapes[dataId] = [[], np.array((1, 0, array.shape[2]))]
-            memmap = self.stream(dataId, {"dtype": "float32", "mode": "w+", "shape": array.shape})
+            memmap = self.stream(dataId, {"dtype": self.getOption("dtype"), "mode": "w+", "shape": array.shape})
 
         shape = self.currentArrayShapes[dataId][1]
         if array.shape[2] != shape[2]:
@@ -87,7 +87,7 @@ class MemmapRecordExporter(DataExporter, IterDataPipe, MapDataPipe):
             memmap = self.stream(
                 dataId,
                 {
-                    "dtype": "float32",
+                    "dtype": self.getOption("dtype"),
                     "mode": "readwrite",
                     "shape": tuple(shape.tolist()),
                 },
