@@ -3,7 +3,6 @@ from sklearn.metrics import confusion_matrix
 
 # from .model.EventManager import EventManager
 
-
 class Scorer:
     title = "Segmentbasiert"
     cmScaleByClass = 4
@@ -16,6 +15,7 @@ class Scorer:
         return metricName
 
     def beforeLoss(self, x, y):
+        """can be overwritten to tranform for a required format for the loss function"""
         return x, y
 
     def __init__(self, numClasses=None, classNames=None, trace=False, threshold=None) -> None:
@@ -34,6 +34,10 @@ class Scorer:
         self.addEvents = False
         self.mapping = None
         self.threshold = threshold
+        
+    def prepareInput(self, inputArray):
+        """can be overwritten to tranform tensors to numpy"""
+        return inputArray
 
     def preparePrediction(self, inputArray):
         # for classification task the shape can be (recordcount?, predictions, classCount)
@@ -52,6 +56,8 @@ class Scorer:
         return inputArray.reshape(-1)
 
     def score(self, truth, prediction, recordName=None, trace=True):
+        prediction = self.prepareInput(prediction)
+        truth = self.prepareInput(truth)
         prediction = self.preparePrediction(prediction)
         truth = self.prepareTruth(truth)
 
@@ -240,6 +246,8 @@ class Scorer:
 
     def getMetricScorer(self, metricName):
         def score(truth, prediction):
+            prediction = self.prepareInput(prediction)
+            truth = self.prepareInput(truth)
             prediction = self.preparePrediction(prediction)
             truth = self.prepareTruth(truth)
             self.results = {}
